@@ -1,8 +1,9 @@
 .locfitW <- function(p,q,w) {
   l <- log(q+1)
-  data=data.frame(cbind(p,l,w))
+  c=c(rep(1,length(p)))
+  data=data.frame(cbind(p,l,c,w))
   ID <- which(rowSums(is.na(data))>0)
   #  data <- data[-ID,]
-  fit=locfit(w~lp(p,l),data=data,family="gamma")
+  fit=locfit(w~lp(p,l,c),data=data,family="gamma")
   return(fit)
 }
\ No newline at end of file
